@@ -36,6 +36,8 @@ typedef int SOCKET;
 #define SOCKET_ERROR -1
 #endif
 
+#define TO_DBL(_var) static_cast<double>(_var)
+
 #ifdef __cplusplus
 //lint -sem(dcc_get::destroy,cleanup)
 class dcc_get {
@@ -113,6 +115,8 @@ void cmd_dcc(const char *);
 
 void dcc_init(void);
 void dcc_deinit(void);
+
+int imax_to_int(const char *, const intmax_t);
 __SWIRC_END_DECLS
 
 #ifdef __cplusplus
