@@ -127,6 +127,11 @@ public:
 	ftp_ctl_conn();
 	~ftp_ctl_conn();
 
+	ftp_ctl_conn &operator=(const ftp_ctl_conn &);
+	ftp_ctl_conn(const ftp_ctl_conn &);
+	ftp_ctl_conn &operator=(ftp_ctl_conn &&);
+	ftp_ctl_conn(ftp_ctl_conn &&);
+
 	std::vector<FTP_REPLY> reply_vec;
 
 	SOCKET		get_sock(void) const;
@@ -149,6 +154,11 @@ public:
 	explicit ftp_data_conn(CSTRING);
 	~ftp_data_conn();
 
+	ftp_data_conn &operator=(const ftp_data_conn &);
+	ftp_data_conn(const ftp_data_conn &);
+	ftp_data_conn &operator=(ftp_data_conn &&);
+	ftp_data_conn(ftp_data_conn &&);
+
 	STRING full_path, path;
 	intmax_t filesz;
 	std::vector<std::string> vec;
