@@ -1,7 +1,7 @@
 #ifndef COMMAND_HELP_H
 #define COMMAND_HELP_H
 /* commandhelp.h
-   Copyright (C) 2018-2025 Markus Uhlin. All rights reserved.
+   Copyright (C) 2018-2026 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -459,6 +459,19 @@ static usage_t list_usage = {
   "",
 };
 
+static usage_t log_usage = {
+  N_("usage:"),
+  "    /log <[clear|ls|rm|scandir|view]> [args]",
+  "    /log clear",
+  "    /log ls <[dir|scanned]>",
+  "    /log rm <#>",
+  "    /log scandir",
+  "    /log view <#>",
+  "",
+  N_("Management of log files."),
+  "",
+};
+
 static usage_t me_usage = {
   N_("usage: /me <message>"),
   "",
