@@ -1,5 +1,5 @@
 /* Input output loop
-   Copyright (C) 2014-2025 Markus Uhlin. All rights reserved.
+   Copyright (C) 2014-2026 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -67,6 +67,7 @@
 #include "commands/invite.h"
 #include "commands/jp.h"
 #include "commands/kick.h"
+#include "commands/log.h"
 #include "commands/me.h"
 #include "commands/misc.h"
 #include "commands/msg.h"
@@ -143,6 +144,7 @@ static struct cmds_tag {
 	{ "kill",        cmd_kill,        true,  kill_usage,        ARRAY_SIZE(kill_usage),        true  },
 	{ "kline",       cmd_kline,       true,  kline_usage,       ARRAY_SIZE(kline_usage),       true  },
 	{ "list",        cmd_list,        true,  list_usage,        ARRAY_SIZE(list_usage),        false },
+	{ "log",         cmd_log,         false, log_usage,         ARRAY_SIZE(log_usage),         false },
 	{ "me",          cmd_me,          true,  me_usage,          ARRAY_SIZE(me_usage),          true  },
 	{ "mode",        cmd_mode,        true,  mode_usage,        ARRAY_SIZE(mode_usage),        true  },
 	{ "msg",         cmd_msg,         true,  msg_usage,         ARRAY_SIZE(msg_usage),         true  },
@@ -649,6 +651,8 @@ get_prompt(void)
 	static const size_t	 minimum_cols = sizeof "#abc...: ";
 
 	if (strings_match_ignore_case(ACTWINLABEL, g_status_window_label) ||
+	    *(g_active_window->label) == g_sym_logwin ||
+	    g_active_window->is_logwin ||
 	    COLS < size_to_int(minimum_cols))
 		return sw_strdup("");
 
@@ -788,6 +792,9 @@ transmit_user_input(CSTRING winlabel, CSTRING input)
 	if (ctx.window == NULL) {
 		err_log(0, "%s: window %s not found", __func__, winlabel);
 		return;
+	} else if (ctx.window->is_logwin) {
+		printtext_print("warn", "cannot transmit to a log window");
+		return;
 	}
 
 	if (g_icb_mode) {
