@@ -53,7 +53,7 @@ typedef enum {
 __SWIRC_BEGIN_DECLS
 
 /* From network-openssl.c */
-extern char *g_ca_file;
+extern STRING g_ca_file;
 
 /*
  * net_send_fake() store the sent data into this buffer
@@ -79,11 +79,10 @@ extern int g_socket_address_family;
 bool		 sasl_is_enabled(void);
 conn_res_t	 net_connect(const struct network_connect_context *,
 		     long int *sleep_time_seconds);
-int		 net_send_fake(const char *, ...);
-struct addrinfo *net_addr_resolve(const char *host, const char *port);
-struct server	*server_new(const char *host, const char *port,
-		     const char *pass);
-void		 destroy_null_bytes_exported(char *, const int);
+int		 net_send_fake(CSTRING, ...);
+struct addrinfo *net_addr_resolve(CSTRING host, CSTRING port);
+struct server	*server_new(CSTRING host, CSTRING port, CSTRING pass);
+void		 destroy_null_bytes_exported(STRING, const int);
 void		 net_connect_clean_up(void);
 void		 net_irc_listen(bool *connection_lost);
 void		 net_kill_connection(void);
@@ -95,10 +94,10 @@ void	net_set_sock_addr_family_ipv6(void);
 
 int	 net_ssl_begin(void);
 void	 net_ssl_end(void);
-int	 net_ssl_check_hostname(const char *, unsigned int);
+int	 net_ssl_check_hostname(CSTRING, unsigned int);
 SSL	*net_ssl_getobj(void);
-int	 net_ssl_send(const char *, ...);
-int	 net_ssl_recv(struct network_recv_context *, char *, int);
+int	 net_ssl_send(CSTRING, ...);
+int	 net_ssl_recv(struct network_recv_context *, STRING, int);
 void	 net_ssl_init(void);
 void	 net_ssl_deinit(void);
 
