@@ -12,6 +12,11 @@ public:
 	explicit suggestion(CSTRING);
 	~suggestion();
 
+	suggestion &operator=(const suggestion &);
+	suggestion(const suggestion &);
+	suggestion &operator=(suggestion &&);
+	suggestion(suggestion &&);
+
 	CSTRING		get_word(void) const;
 	CWSTRING	get_wide_word(void) const;
 
