@@ -36,12 +36,6 @@
 #include "printtext.h"
 #include "strHand.h"
 
-#if defined(UNIX)
-#define PRINT_SIZE	"%zu"
-#elif defined(WIN32)
-#define PRINT_SIZE	"%Iu"
-#endif
-
 #define MBS_SIZE 6144
 #define TMP_SIZE 4096
 
