@@ -1,5 +1,5 @@
 /* Window functions
-   Copyright (C) 2012-2025 Markus Uhlin. All rights reserved.
+   Copyright (C) 2012-2026 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -31,6 +31,7 @@
 #if defined(UNIX) && USE_LIBNOTIFY
 #include <libnotify/notify.h>
 #endif
+#include "commands/log.h"
 #include "commands/misc.h"
 #ifdef WIN32
 #include "compat/stdlib.h" /* arc4random() */
@@ -251,6 +252,7 @@ hInstall(const struct hInstall_context *ctx)
 	}
 
 	entry->buf                  = textBuf_new();
+	entry->is_logwin            = false;
 	entry->logging              = false;
 	entry->received_chancreated = false;
 	entry->received_chanmodes   = false;
@@ -795,7 +797,9 @@ spawn_chat_window(CSTRING label, CSTRING title)
 	 */
 	if (atomic_load_bool(&g_on_air) &&
 	    !is_irc_channel(entry->label) &&
-	    !g_icb_mode)
+	    !g_icb_mode &&
+	    *(entry->label) != g_sym_logwin &&
+	    !entry->is_logwin)
 		cmd_whois(entry->label);
 
 	return 0;
@@ -832,7 +836,8 @@ window_close_all_priv_conv(void)
 	FOREACH_HASH_TABLE_ENTRY() {
 		FOREACH_WINDOW_IN_ENTRY() {
 			if (window == g_status_window ||
-			    is_irc_channel(window->label))
+			    is_irc_channel(window->label) ||
+			    window->is_logwin)
 				continue;
 			if (window->label &&
 			    pc_assigned < ARRAY_SIZE(priv_conv)) {
